@@ -582,6 +582,9 @@ var ChangeForm = AdminForm.extend({
 	},
 
 	set_interaction: function() {
+		// TODO: add Django-like behavior:
+		// - fieldsets should be split into tabs
+		// - collapsible areas should work, etc.
 		enhance_textareas(this.form);
 		enhance_comboboxes(this.form);
 		enhance_jsontextareas(this.form);
@@ -786,13 +789,13 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 		this.uiDialog.dialog('option', 'zIndex', 1200); // set z-index here, because it can't set by _super
 
 		// enhance action button
-		var actionButton = this.uiDialog.parent().find(':button:contains("Action")');
-		actionButton.attr('id', 'action-button');
+		var action_button = this.uiDialog.parent().find(':button:contains("Action")');
+		action_button.attr('id', 'action-button');
 
-		actionButton.find('.ui-button-text').text(gettext('Select'));
+		action_button.find('.ui-button-text').text(gettext('Select'));
 
-		actionButton.attr('disabled', 'disabled');
-		actionButton.addClass('ui-button-disabled ui-state-disabled');
+		action_button.attr('disabled', 'disabled');
+		action_button.addClass('ui-button-disabled ui-state-disabled');
 
 		this.uiDialog.dialog('option', 'title', gettext('Select a file'));
 
@@ -2254,11 +2257,13 @@ var FiberItem = Class.extend({
 
 	// TODO: move to content item specific class (edit)
 	edit_content_item: function() {
-		adminPage.hide_admin_elements();
+		if (this.element_data.url) {
+			adminPage.hide_admin_elements();
 
-		new ChangeContentItemFormDialog({
-			url: this.element_data.url
-		});
+			new ChangeContentItemFormDialog({
+				url: this.element_data.url
+			});
+		}
 	}
 });
 
